package com.fs.app.controller;


import com.fs.app.annotation.Login;
import com.fs.common.core.domain.ResponseResult;
import com.fs.company.domain.CompanyUser;
import com.fs.company.service.ICompanyTagUserService;
import com.fs.company.service.ICompanyUserService;
import com.fs.store.param.h5.FsUserPageListParam;
import com.fs.store.param.h5.TagListParam;
import com.fs.store.service.IFsUserService;
import com.fs.store.vo.h5.CompanyUserTagListVO;
import com.fs.store.vo.h5.FsUserPageListVO;
import com.fs.store.vo.h5.UserDetailsVO;
import com.fs.store.vo.h5.UserListPageVO;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;


@Api(tags = "用户会员相关接口")
@RestController
@RequestMapping("/app/fs/user")
public class FsUserController extends AppBaseController {


    @Autowired
    private IFsUserService fsUserService;

    @Autowired
    private ICompanyUserService companyUserService;

    @Autowired
    private ICompanyTagUserService companyTagUserService;
//
//    @Autowired
//    private IQwTagService tagService;

    @Login
    @PostMapping("/pageList")
    @ApiOperation("用户会员分页列表")
    public ResponseResult<PageInfo<FsUserPageListVO>> pageList(@RequestBody FsUserPageListParam param) {
        param.setUserId(Long.parseLong(getUserId()));
        PageHelper.startPage(param.getPageNum(), param.getPageSize());
        List<FsUserPageListVO> list = fsUserService.selectFsUserPageList(param);
        PageInfo<FsUserPageListVO> pageInfo = new PageInfo<>(list);
        return ResponseResult.ok(pageInfo);
    }

    @GetMapping("/allCompanyUser")
    @ApiOperation("获取所有公司销售")
    public ResponseResult<List<CompanyUser>> getAllCompanyUser(){
        List<CompanyUser> companyUsers = companyUserService.selectAllCompanyUserByParentId(Long.parseLong(getUserId()));
        return ResponseResult.ok(companyUsers);
    }

    @Login
    @GetMapping("/totalNumber")
    @ApiOperation("用户会员数量统计")
    public ResponseResult<UserListPageVO> getTotalNumber() {
        UserListPageVO userNumber = fsUserService.getUserNumber(Long.parseLong(getUserId()));
        return ResponseResult.ok(userNumber);
    }

    @Login
    @GetMapping("/details")
    @ApiOperation("用户会员详情")
    public ResponseResult<UserDetailsVO> getUserDetails(@ApiParam(value = "用户id", required = true) @RequestParam Long userId,
                                                                   @ApiParam(value = "时间tab，不传表示查询全部，分别是：今天、昨天、前天、近七天", required = true) @RequestParam(required = false) String dateTag) {
        UserDetailsVO userDetails = fsUserService.getUserDetails(Long.parseLong(getUserId()), userId, dateTag);
        return ResponseResult.ok(userDetails);
    }

    @Login
    @GetMapping("/tagList")
    @ApiOperation("用户会员标签列表")
    public ResponseResult<PageInfo<CompanyUserTagListVO>> getTagList(TagListParam param) {
        param.setUserId(Long.parseLong(getUserId()));
        PageHelper.startPage(param.getPageNum(), param.getPageSize());
        List<CompanyUserTagListVO> tagList = companyTagUserService.getTagList(param);
        PageInfo<CompanyUserTagListVO> pageInfo = new PageInfo<>(tagList);
        return ResponseResult.ok(pageInfo);
    }

    @Login
    @PostMapping("/disabled")
    @ApiOperation("批量禁用会员")
    public ResponseResult<Boolean> disabledUser(@ApiParam(value = "联系人id集合", required = true) @RequestBody String[] ids) {
        Boolean r = fsUserService.disabledUser(ids, false);
        return ResponseResult.ok(r);
    }

    @Login
    @PostMapping("/enabled")
    @ApiOperation("批量启用会员")
    public ResponseResult<Boolean> enabledUser(@ApiParam(value = "联系人id集合", required = true) @RequestBody String[] ids) {
        Boolean r = fsUserService.disabledUser(ids, true);
        return ResponseResult.ok(r);
    }


}
